@@ -1,32 +1,25 @@
-use super::method_gen;
-use super::util::*;
+use super::{method_gen, util::*};
 use crate::model::{Method, MethodArgument};
 
 fn generate_key_snippet(key_args: &[MethodArgument], identifier: &str) -> proc_macro2::TokenStream {
     let id_literal = byte_str_literal(identifier.as_bytes());
-    if key_args.is_empty() {
-        // hardcode key
-        quote! {
-            let key: &'static [u8] = #id_literal;
-        }
-    } else {
-        // build key from arguments
-        let key_appends: Vec<proc_macro2::TokenStream> = key_args
-            .iter()
-            .map(|arg| {
-                let arg_pat = &arg.pat;
-                // TODO: needs to be converted to dep_encode_or_exit
-                quote! {
-                    if let Result::Err(encode_error) = #arg_pat.dep_encode(&mut key) {
-                        self.get_storage_raw().signal_error(encode_error.message_bytes());
-                    }
-                }
-            })
-            .collect();
-        quote! {
-            let mut key: Vec<u8> = #id_literal.to_vec();
-            #(#key_appends)*
-        }
+
+    // build base key from arguments
+    let key_appends: Vec<proc_macro2::TokenStream> = key_args
+        .iter()
+        .map(|arg| {
+            let arg_pat = &arg.pat;
+            quote! {
+                ___key___.append_item(& #arg_pat);
+            }
+        })
+        .collect();
+    quote! {
+        let mut ___key___ = elrond_wasm::storage::StorageKey::<Self::Api>::new(
+            self.raw_vm_api(),
+            &#id_literal[..],
+        );
+        #(#key_appends)*
     }
 }
 
@@ -39,7 +32,7 @@ pub fn generate_getter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
             quote! {
                 #msig {
                     #key_snippet
-                    elrond_wasm::storage_get(self.get_storage_raw(), &key[..])
+                    elrond_wasm::storage::storage_get(self.raw_vm_api(), &___key___)
                 }
             }
         },
@@ -61,7 +54,7 @@ pub fn generate_setter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
     quote! {
         #msig {
             #key_snippet
-            elrond_wasm::storage_set(self.get_storage_raw(), &key[..], & #pat);
+            elrond_wasm::storage::storage_set(self.raw_vm_api(), &___key___, & #pat);
         }
     }
 }
@@ -75,9 +68,9 @@ pub fn generate_mapper_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
             quote! {
                 #msig {
                     #key_snippet
-                    <#ty as elrond_wasm::storage::mappers::StorageMapper<Self::Storage>>::new(
-                        self.get_storage_raw(),
-                        elrond_wasm::types::BoxedBytes::from(key),
+                    <#ty as elrond_wasm::storage::mappers::StorageMapper<Self::Api>>::new(
+                        self.raw_vm_api(),
+                        ___key___
                     )
                 }
             }
@@ -91,7 +84,7 @@ pub fn generate_is_empty_impl(m: &Method, identifier: &str) -> proc_macro2::Toke
     quote! {
         #msig {
             #key_snippet
-            elrond_wasm::api::StorageReadApi::storage_load_len(&self.get_storage_raw(), &key[..]) == 0
+            elrond_wasm::storage::storage_get_len(self.raw_vm_api(), &___key___) == 0
         }
     }
 }
@@ -105,7 +98,7 @@ pub fn generate_clear_impl(m: &Method, identifier: &str) -> proc_macro2::TokenSt
     quote! {
         #msig {
             #key_snippet
-            elrond_wasm::api::StorageWriteApi::storage_store_slice_u8(&self.get_storage_raw(), &key[..], &[]);
+            elrond_wasm::storage::storage_clear(self.raw_vm_api(), &___key___);
         }
     }
 }
